' ========================================================================================
' Setting JPEG Compression Level
' ========================================================================================

' ========================================================================================
' To specify the compression level when you save a JPEG image, initialize an
' EncoderParameters structure and pass the address of that object to the
' function. Initialize the EncoderParameters structure so that it has an array consisting
' of one EncoderParameter structure. Initialize that one EncoderParameter structure so
' that its Value member points to a DWORD value from 0 through 100. Set the Guid member of
' the EncoderParameter structure to $EncoderQuality.
' The following console application saves three JPEG images, each with a different quality
' level. A quality level of 0 corresponds to the greatest compression, and a quality level
' of 100 corresponds to the least compression.
' The main function relies on the helper function GdiPlusGetEncoderClsid to retrieve the
' guid of the TIFF encoder.
' ========================================================================================

' SED_PBCC
#COMPILE EXE
#DIM ALL
#INCLUDE "GDIPLUS.INC"
#INCLUDE "GDIPUTILS.INC"

' ========================================================================================
' Main
' ========================================================================================
FUNCTION PBMAIN

   LOCAL hStatus AS LONG
   LOCAL token AS DWORD
   LOCAL StartupInput AS GdiplusStartupInput
   LOCAL EncoderClsid AS GUID
   LOCAL pImage AS DWORD
   LOCAL eps AS EncoderParameters
   LOCAL ep AS EncoderParameter
   LOCAL dwQuality AS DWORD
   LOCAL strFileName AS STRING

   ' // Initialize GDI+
   StartupInput.GdiplusVersion = 1
   hStatus = GdiplusStartup(token, StartupInput, BYVAL %NULL)
   IF hStatus THEN
      PRINT "Error initializing GDI+"
      EXIT FUNCTION
   END IF

   strFileName = UCODE$("Shapes.bmp")
   hStatus = GdipLoadImageFromFile(STRPTR(strFileName), pImage)

   ' // Get the CLSID of the JPEG encoder.
   EncoderClsid = GUID$(GdiPlusGetEncoderClsid("image/jpeg"))

   ' // Before we call GdipSaveImageToFile, we must initialize an
   ' // EncoderParameters structure The EncoderParameters structure
   ' // has an array of EncoderParameter structures In this
   ' // case, there is only one EncoderParameter structure in the array.
   ' // The one EncoderParameter structure has an array of values.
   ' // In this case, there is only one value (of type DWORD)
   ' // in the array. We will let this value vary from 0 to 100.

   eps.count = 1
   eps.Parameter(0).pGuid = $EncoderQuality
   eps.Parameter(0).dwType = %EncoderParameterValueTypeLong
   eps.Parameter(0).NumberOfValues = 1

   ' // Save the image as a JPEG with quality level 0.
   dwQuality = 0
   eps.Parameter(0).Value = VARPTR(dwQuality)
   strFileName = UCODE$("Shapes001.jpg")
   hStatus = GdipSaveImageToFile(pImage, STRPTR(strFileName), EncoderClsid, eps)
   IF hStatus = %StatusOk THEN PRINT "Shapes001.jpg saved successfully"

   ' // Save the image as a JPEG with quality level 50.
   dwQuality = 50
   eps.Parameter(0).Value = VARPTR(dwQuality)
   strFileName = UCODE$("Shapes050.jpg")
   hStatus = GdipSaveImageToFile(pImage, STRPTR(strFileName), EncoderClsid, eps)
   IF hStatus = %StatusOk THEN PRINT "Shapes050.jpg saved successfully"

   ' // Save the image as a JPEG with quality level 100.
   dwQuality = 100
   eps.Parameter(0).Value = VARPTR(dwQuality)
   strFileName = UCODE$("Shapes100.jpg")
   hStatus = GdipSaveImageToFile(pImage, STRPTR(strFileName), EncoderClsid, eps)
   IF hStatus = %StatusOk THEN PRINT "Shapes100.jpg saved successfully"

   ' // Cleanup
   IF pImage THEN GdipDisposeImage(pImage)

   ' // Shutdown GDI+
   GdiplusShutdown token

   WAITKEY$

END FUNCTION
' ========================================================================================
